(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     26998,        913]*)
(*NotebookOutlinePosition[     28781,        968]*)
(*  CellTagsIndexPosition[     28737,        964]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Table of Contents", "Title",
  CounterAssignments->{{"Title", 3}}],

Cell[TextData[{
  StyleBox["Introduction",
    FontWeight->"Bold"],
  "\t\t\t\t\t\t\t\t\t\t\t\t  ",
  StyleBox["13",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["1. Description of Diffusion",
    FontWeight->"Bold"],
  "\t\t\t\t\t\t\t\t\t\t  ",
  StyleBox["15",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "   1.1. Description of Normal Diffusion\t\t\t\t\t\t\t\t  15\n      1.1.1. \
Plan of Action\t\t\t\t\t\t\t\t\t\t  15\n      1.1.2. Fick's Diffusion\t\t\t\t\
\t\t\t\t\t\t  15\n         ",
  StyleBox["1.1.2.1. Fick's Laws",
    FontSize->10],
  "\n         ",
  StyleBox["1.1.2.2. Propagator of Fick's Diffusion",
    FontSize->10],
  "\n         ",
  StyleBox["1.1.2.3. Normal Distribution and Einstein's Relation",
    FontSize->10],
  "\n      1.1.3. Normal Diffusion due to Cattaneo\t\t\t\t\t\t\t\t  17\n      \
1.1.4. Normal Diffusion due to Diffusion Principle \t\t\t\t\t\t  18\n         \
",
  StyleBox["1.1.4.1. Verbal Formulation of Diffusion Principle",
    FontSize->10],
  "\n         ",
  StyleBox["1.1.4.2. Superposition Possibility",
    FontSize->10],
  "\n         ",
  StyleBox["1.1.4.3. Difference Equation",
    FontSize->10],
  "\n         ",
  StyleBox["1.1.4.4. Solution to the Difference Equation",
    FontSize->10],
  "\n         ",
  StyleBox["1.1.4.5. Transition to a Differential Equation",
    FontSize->10],
  "\n      1.1.5. Further Proceeding   \t\t\t\t\t\t\t\t\t  21\n         ",
  StyleBox["1.1.5.1. Limit Calculation to Fick's Diffusion Equation",
    FontSize->10],
  "\n         ",
  StyleBox["1.1.5.2. Hypothesis on Variance",
    FontSize->10]
}], "Text"],

Cell[TextData[{
  "   1.2. Classification of Diffusion\t\t\t\t\t\t\t\t\t  23\n      1.2.1. \
Comparing Measured Data with Theoretical Propagators\t\t\t\t\t  23\n         \
",
  StyleBox["1.2.1.1. Problem",
    FontSize->10],
  "\n         ",
  StyleBox["1.2.1.2. Variance Theorem",
    FontSize->10],
  "\n         ",
  StyleBox["1.2.1.3. Importance of the Variance Theorem",
    FontSize->10],
  "\n      1.2.2. Classification of Transport Processes via Variance\t\t\t\t\t\
  24\n         ",
  StyleBox["1.2.2.1. Confirmation of Einstein's Relation",
    FontSize->10],
  "\n         ",
  StyleBox["1.2.2.2. Variance of the Static Wave Propagator",
    FontSize->10],
  "\n         ",
  StyleBox["1.2.2.3. Classification Scheme of Diffusive Prozesses",
    FontSize->10],
  "\n      1.2.3. Further Aspects of Diffusion Description\t\t\t\t\t\t\t  26\n\
         ",
  StyleBox["1.2.3.1. How to Deal with Drift in Dynamics",
    FontSize->10],
  "\n         ",
  StyleBox["1.2.3.2. Generalization to Several Space Dimensions",
    FontSize->10]
}], "Text"],

Cell["\<\
   1.3. Description of Anomalous Diffusion\t\t\t\t\t\t\t\t  28
      1.3.1. The Formula by Wei, Bechinger, and Leiderer\t\t\t\t\t\t  28
      1.3.2. Time Fractional Diffusion Equations\t\t\t\t\t\t\t  28
      1.3.3. Space Fractional Diffusion Equations\t\t\t\t\t\t\t  29
      1.3.4. Space and Time Fractional Diffusion Equations\t\t\t\t\t\t  30\
\>", "Text"],

Cell["   1.4. Summary\t\t\t\t\t\t\t\t\t\t\t  30", "Text",
  PageBreakBelow->True],

Cell[TextData[{
  StyleBox["2. Mathematical Methods",
    FontWeight->"Bold"],
  "\t\t\t\t\t\t\t\t\t\t  ",
  StyleBox["31",
    FontWeight->"Bold"]
}], "Text"],

Cell["   2.1. Motivation\t\t\t\t\t\t\t\t\t\t\t  31", "Text"],

Cell[TextData[{
  "   2.2. Dirac's Delta Function\t\t\t\t\t\t\t\t\t\t  31\n      2.2.1. \
Singular Integrals\t\t\t\t\t\t\t\t\t\t  31\n      2.2.2. Fourier \
Transformation of Number One\t\t\t\t\t\t\t  32\n         ",
  StyleBox["2.2.2.1. Properties of Fourier Transformation",
    FontSize->10],
  "\n         ",
  StyleBox["2.2.2.2. Application of the Mean Value Theorem",
    FontSize->10],
  "\n         ",
  StyleBox["2.2.2.3. Definition of the Delta Function due to Dirac",
    FontSize->10],
  "\n         ",
  StyleBox[
  "2.2.2.4. Determination of the Multiplicator of the Fourier Transformation",
    
    FontSize->10],
  "\n      2.2.3. Mellin Transformation of Number One \t\t\t\t\t\t\t  34\n    \
     ",
  StyleBox["2.2.3.1. Result from Fourier Transformation",
    FontSize->10],
  "\n         ",
  StyleBox["2.2.3.2. Mellin Residue of the Delta Function",
    FontSize->10],
  "\n         ",
  StyleBox["2.2.3.3. Independent Confirmation",
    FontSize->10],
  "\n         ",
  StyleBox["2.2.3.4. Consequences from the Theorem by Mellin",
    FontSize->10],
  "\n      2.2.4. The Momenta of the Delta Function  \t\t\t\t\t\t\t  37\n     \
    ",
  StyleBox["2.2.4.1. Connection between Mellin Transformation and Momenta",
    FontSize->10],
  "\n         ",
  StyleBox["2.2.4.2. Calculation of the Delta Momenta",
    FontSize->10],
  "\n         ",
  StyleBox["2.2.4.3. Possibilities of Enlarging Function Theory",
    FontSize->10]
}], "Text"],

Cell[TextData[{
  "   2.3. Laplace and Fourier Transformation\t\t\t\t\t\t\t\t  39\n      \
2.3.1. Known Relations\t\t\t\t\t\t\t\t\t\t  39\n         ",
  StyleBox["2.3.1.1. Plan of Action",
    FontSize->10],
  "\n         ",
  StyleBox["2.3.1.2. Idea of Propagator",
    FontSize->10],
  "\n         ",
  StyleBox["2.3.1.3. Idea of Green's Function",
    FontSize->10],
  "\n      2.3.2. Prolongations\t\t\t\t\t\t\t\t\t\t  41\n         ",
  StyleBox["2.3.2.1. Laplace Transformation of the Delta Function",
    FontSize->10],
  "\n         ",
  StyleBox["2.3.2.2. Consequences for Computer Algebra",
    FontSize->10],
  "\n         ",
  StyleBox["2.3.2.3. Laplace Convolution with Delta Function",
    FontSize->10],
  "\n         ",
  StyleBox["2.3.2.4. Space and Time Dependent Steering Functions",
    FontSize->10],
  "\n         ",
  StyleBox["2.3.2.5. Space Dependent Analytical Coefficients",
    FontSize->10],
  "\n         ",
  StyleBox["2.3.2.6. Fourier Transformation of the Riesz Operator",
    FontSize->10]
}], "Text"],

Cell[TextData[{
  "   2.4. Mellin Transformation\t\t\t\t\t\t\t\t\t\t  45\n      2.4.1. \
Difference Equations\t\t\t\t\t\t\t\t\t  45\n         ",
  StyleBox["2.4.1.1. Generating Linear Difference Equations",
    FontSize->10],
  "\n         ",
  StyleBox["2.4.1.2. Solution to Linear Difference Equations",
    FontSize->10],
  "\n         ",
  StyleBox["2.4.1.3. Fox's H-Functions",
    FontSize->10],
  "\n      2.4.2. Momenta Calculation from Laplace Transforms\t\t\t\t\t\t  47\
\n         ",
  StyleBox["2.4.2.1. Motivation",
    FontSize->10],
  "\n         ",
  StyleBox["2.4.2.2. Calculation",
    FontSize->10],
  "\n      2.4.3. Momenta Calculation from Fourier Transforms\t\t\t\t\t\t  48\
\n         ",
  StyleBox["2.4.3.1. Direct Calculation",
    FontSize->10],
  "\n         ",
  StyleBox["2.4.3.2. Momenta of a Fourier Convolution",
    FontSize->10]
}], "Text"],

Cell["   2.5. Summary\t\t\t\t\t\t\t\t\t\t\t  49", "Text",
  PageBreakBelow->True],

Cell[TextData[{
  StyleBox["3. Solution to Fractional Diffusion Equations",
    FontWeight->"Bold"],
  "\t\t\t\t\t\t\t  ",
  StyleBox["51",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "   3.1. Solution to the Equation by Schneider and Wyss\t\t\t\t\t\t  51\n   \
   3.1.1. Optimized Representation of the Equation\t\t\t\t\t\t\t  51\n      \
3.1.2. Solution Path\t\t\t\t\t\t\t\t\t\t  53\n         ",
  StyleBox["3.1.2.1. Laplace Transformation",
    FontSize->10],
  "\n         ",
  StyleBox["3.1.2.2. Following Fourier Transformation",
    FontSize->10],
  "\n         ",
  StyleBox["3.1.2.3. Fourier Transform of the Solution",
    FontSize->10],
  "\n         ",
  StyleBox["3.1.2.4. Solution Function by Schneider and Wyss",
    FontSize->10],
  "\n      3.1.3. Solution Properties\t\t\t\t\t\t\t\t\t\t  56\n         ",
  StyleBox["3.1.3.1. Solution Momenta",
    FontSize->10],
  "\n         ",
  StyleBox["3.1.3.2. Series Representation and Asymptotics of the Solution",
    FontSize->10],
  "\n         ",
  StyleBox[
  "3.1.3.3. Graphic Representation of the One Dimensional Propagators",
    FontSize->10],
  "\n         ",
  StyleBox["3.1.3.4. Similarity Representation of the Solution",
    FontSize->10],
  "\t\n         ",
  StyleBox["3.1.3.5. Interesting Special Cases of the Solution",
    FontSize->10]
}], "Text"],

Cell[TextData[{
  "   3.2. Further Dynamic Equations\t\t\t\t\t\t\t\t\t  63\n      3.2.1. \
Equation to the Solution by Wei et al.\t\t\t\t\t\t\t  63\n         ",
  StyleBox["3.2.1.1. Access in Fourier Space",
    FontSize->10],
  "\n         ",
  StyleBox["3.2.1.2. Leading to the Formula by Wei et al.",
    FontSize->10],
  "\n         ",
  StyleBox["3.2.1.3. Laplace and Fourier Transform",
    FontSize->10],
  "\n         ",
  StyleBox["3.2.1.4. Problems",
    FontSize->10],
  "\n      3.2.2. Way out\t\t\t\t\t\t\t\t\t\t\t  67"
}], "Text"],

Cell[TextData[{
  "   3.3. Solution to the Time and Space Fractional Diffusion Equation  \t\t\
\t\t  68\n      3.3.1. Motivation\t\t\t\t\t\t\t\t\t\t\t  68\n      3.3.2. \
Solution to the Equation\t\t\t\t\t\t\t\t\t  69\n         ",
  StyleBox["3.3.2.1. Representation of the Equation",
    FontSize->10],
  "\n         ",
  StyleBox["3.3.2.2. Laplace Transformation of the Equation",
    FontSize->10],
  "\n         ",
  StyleBox["3.3.2.3. Following Fourier Transformation",
    FontSize->10],
  "\n         ",
  StyleBox["3.3.2.4. Transforms of the Solution",
    FontSize->10],
  "\n         ",
  StyleBox["3.3.2.5. Solution and Similarity Representation",
    FontSize->10],
  "\n         ",
  StyleBox["3.3.2.6. Base Integrals to the Momenta Densities",
    FontSize->10],
  "\n         ",
  StyleBox["3.3.2.7. Momenta",
    FontSize->10]
}], "Text"],

Cell["   3.4. Summary\t\t\t\t\t\t\t\t\t\t\t  74", "Text",
  PageBreakBelow->True],

Cell[TextData[{
  StyleBox["4. Discussion of Nucler Magnetic Relaxation",
    FontWeight->"Bold"],
  "\t\t\t\t\t\t\t  ",
  StyleBox["75",
    FontWeight->"Bold"]
}], "Text"],

Cell["   4.1. Leading to the Task\t\t\t\t\t\t\t\t\t\t  75", "Text"],

Cell[TextData[{
  "   4.2. Importance and Determination of the Structure Factor  \t\t\t\t\t  \
75\n      4.2.1. Correlation Function  \t\t\t\t\t\t\t\t\t  75\n      4.2.2. \
Mathematical Aspects\t\t\t\t\t\t\t\t\t  77\n         ",
  StyleBox["4.2.2.1. Fourier Convolution in Several Dimensions",
    FontSize->10],
  "\n         ",
  StyleBox["4.2.2.2. Inverse Fourier Transformation in Several Dimensions",
    FontSize->10],
  "\n      4.2.3. Influence of Fractal Surfaces  \t\t\t\t\t\t\t\t  79"
}], "Text"],

Cell[TextData[{
  "   4.3. Power Law for the Relaxation Rate ",
  Cell[BoxData[
      \(TraditionalForm\`T\_1\)]],
  "  \t\t\t\t\t\t\t  81\n      4.3.1. Evaluating Formula\t\t\t\t\t\t\t\t\t\t  \
81\n      4.3.2. Measurement on Relaxation Rate ",
  Cell[BoxData[
      \(TraditionalForm\`T\_1\)]],
  "  \t\t\t\t\t\t\t  82\n      4.3.3. Comparison of Theory and Measured Data  \
\t\t\t\t\t\t  83"
}], "Text"],

Cell["\<\
   4.4. Summary\t\t\t\t\t\t\t\t\t\t\t  84
\
\>", "Text"],

Cell[TextData[{
  StyleBox["5. Variance Aanalysis of Measured Diffusion Data  ",
    FontWeight->"Bold"],
  StyleBox["\t\t\t\t\t\t  "],
  StyleBox["85",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "   5.1. Analytical Aspects\t\t\t\t\t\t\t\t\t\t  85\n      5.1.1. \
Properties of Measured Diffusion Data\t\t\t\t\t\t\t  85\n         ",
  StyleBox["5.1.1.1. Video Microskopy",
    FontSize->10],
  "\n         ",
  StyleBox["5.1.1.2. Single File Diffusion",
    FontSize->10],
  "\n         ",
  StyleBox["5.1.1.3. Alternative Voigt Profile",
    FontSize->10],
  "\n      5.1.2. Properties of Diffusion Convolutios\t\t\t\t\t\t\t  87\n     \
    ",
  StyleBox["5.1.2.1. Momenta of a Special Fourier Convolution",
    FontSize->10],
  "\n         ",
  StyleBox["5.1.2.2. Variance of a Special Fourier Convolution",
    FontSize->10],
  "\n         ",
  StyleBox["5.1.2.3. Variance of a further Special Fourier Convolution",
    FontSize->10],
  "\n         ",
  StyleBox["5.1.2.4. Analytical Representation of Fourier Convolutions",
    FontSize->10]
}], "Text"],

Cell[TextData[{
  "   5.2. Figures\t\t\t\t\t\t\t\t\t\t\t\t  91\n      5.2.1. First \
Examination of Measured Data  \t\t\t\t\t\t\t  91\n         ",
  StyleBox["5.2.1.1. Variance Trimming",
    FontSize->10],
  "\n         ",
  StyleBox["5.2.1.2. Properties at Distribution Maximum",
    FontSize->10],
  "\n      5.2.2. Figures of Fourier Convolions\t\t\t\t\t\t\t\t  93\n         \
",
  StyleBox["5.2.2.1. Short Times",
    FontSize->10],
  "\n         ",
  StyleBox["5.2.2.2. Long Times",
    FontSize->10],
  "\n         ",
  StyleBox["5.2.2.3. Convolution due to Wei et al.",
    FontSize->10],
  "\n         ",
  StyleBox["5.2.2.4. Comparision of both Theories",
    FontSize->10],
  "\n      5.2.3. Graphic Comparison to Measured Data\t\t\t\t\t\t\t100\n      \
   ",
  StyleBox["5.2.3.1. Schneider Wyss Theory",
    FontSize->10],
  "\n         ",
  StyleBox["5.2.3.2. Formula by Wei et al.",
    FontSize->10],
  "\n         ",
  StyleBox["5.2.3.3. Comparison of both Theories",
    FontSize->10]
}], "Text"],

Cell["   5.3. Summary\t\t\t\t\t\t\t\t\t\t\t103", "Text",
  PageBreakBelow->True],

Cell[TextData[{
  StyleBox["Summary",
    FontWeight->"Bold"],
  "\t\t\t\t\t\t\t\t\t\t\t\t",
  StyleBox["105",
    FontWeight->"Bold"]
}], "Text"],

Cell["\<\
   1. Variance Theorem\t\t\t\t\t\t\t\t\t\t105
   2. Delta Function\t\t\t\t\t\t\t\t\t\t\t106
   3. Anomalous Diffusion\t\t\t\t\t\t\t\t\t\t106
   4. Nuclear Magnetic Relaxation\t\t\t\t\t\t\t\t\t107
   5. Measuring Diffusion\t\t\t\t\t\t\t\t\t\t108
   6. Computer Algebra\t\t\t\t\t\t\t\t\t\t108
   7. Outlook\t\t\t\t\t\t\t\t\t\t\t\t109\
\>", "Text"],

Cell[TextData[{
  StyleBox["Appendices",
    FontWeight->"Bold"],
  "\t\t\t\t\t\t\t\t\t\t\t\t",
  StyleBox["111",
    FontWeight->"Bold"]
}], "Text"],

Cell["\<\
   A. Variance Theorem\t\t\t\t\t\t\t\t\t\t111
      A.1. Definitions\t\t\t\t\t\t\t\t\t\t\t111
      A.2. Proof to the Variance Theorem\t\t\t\t\t\t\t\t112
      A.3. Consequences  \t\t\t\t\t\t\t\t\t\t113\
\>", "Text"],

Cell[TextData[{
  "   B. Integral Transformations\t\t\t\t\t\t\t\t\t\t115\n      B.1. \
Motivation\t\t\t\t\t\t\t\t\t\t\t115\n      B.2. Fourier Transformations\t\t\t\
\t\t\t\t\t\t115\n         ",
  StyleBox["B.2.1. Definitions",
    FontSize->10],
  "\n         ",
  StyleBox["B.2.2. Properties",
    FontSize->10],
  "\n      B.3. Inverse Fourier Transformations\t\t\t\t\t\t\t\t116\n         \
",
  StyleBox["B.3.1. Definitions",
    FontSize->10],
  "\n         ",
  StyleBox["B.3.2. Properties",
    FontSize->10],
  "\n      B.4. Mellin Transformation\t\t\t\t\t\t\t\t\t118\n         ",
  StyleBox["B.4.1. Properties",
    FontSize->10],
  "\n         ",
  StyleBox["B.4.2. Fourier Transformations",
    FontSize->10],
  "\n         ",
  StyleBox["B.4.3. Laplace Transformation",
    FontSize->10],
  "\n         ",
  StyleBox["B.4.4. Integrals",
    FontSize->10]
}], "Text"],

Cell[TextData[{
  "   C. Mittag Leffler Function\t\t\t\t\t\t\t\t\t\t123\n      C.1. \
Definition\t\t\t\t\t\t\t\t\t\t\t123\n      C.2. Inverse Laplace Transform of \
an Algebraic Function\t\t\t\t\t123\n         ",
  StyleBox["C.2.1. Underlying Mellin Transformation",
    FontSize->10],
  "\n         ",
  StyleBox["C.2.2. Idea of Residual Optimizing",
    FontSize->10],
  "\n            ",
  StyleBox["C.2.2.1. Generalization of a Property of Mellin Transformation",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["C.2.2.2. Application Fields to Residual Optimizing",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["C.2.2.3. Established Inconsistencies",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["C.2.3. General Access to the Mittag Leffler Function",
    FontSize->10]
}], "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "   D. Program Description\t\t\t\t\t\t\t\t\t\t129\n      D.1. Survey\t\t\t\t\
\t\t\t\t\t\t\t129\n      D.2. Description of the ",
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  " Packages\t\t\t\t\t\t131\n         ",
  StyleBox["D.2.1. Package ",
    FontSize->10],
  StyleBox["FractionalCalculus.m   ",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t131\n            ",
  StyleBox["D.2.1.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.1.2. Concerned Notebooks",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.1.3. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.2. Package ",
    FontSize->10],
  StyleBox["Options.m",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox["\t",
    FontSize->10],
  "\t\t\t\t\t\t\t\t132\n            ",
  StyleBox["D.2.2.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.2.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.3. Package ",
    FontSize->10],
  StyleBox["Var.m",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t\t\t\t133\n            ",
  StyleBox["D.2.3.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.3.2. New and Supplemented Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.4. Package ",
    FontSize->10],
  StyleBox["Boole.m ",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t\t\t134\n            ",
  StyleBox["D.2.4.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.4.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.4.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.5. Package ",
    FontSize->10],
  StyleBox["Synonyms.m",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox["\t",
    FontSize->10],
  "\t\t\t\t\t\t\t\t136\n            ",
  StyleBox["D.2.5.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.5.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.5.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.6. Package ",
    FontSize->10],
  StyleBox["Gamma.m",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox["\t",
    FontSize->10],
  "\t\t\t\t\t\t\t\t138\n            ",
  StyleBox["D.2.6.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.6.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.7. Package ",
    FontSize->10],
  StyleBox["Fox.m",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t\t\t\t139\n            ",
  StyleBox["D.2.7.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.7.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.8. Package ",
    FontSize->10],
  StyleBox["SymmetricalDelta.m",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t\t140\n            ",
  StyleBox["D.2.8.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.8.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.8.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.9. Package ",
    FontSize->10],
  StyleBox["MellinTr.m",
    FontSize->10,
    FontSlant->"Italic"],
  StyleBox["\t",
    FontSize->10],
  "\t\t\t\t\t\t\t\t141\n            ",
  StyleBox["D.2.9.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.9.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.9.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.10. Package ",
    FontSize->10],
  StyleBox["RiemannL.m    ",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t\t142\n            ",
  StyleBox["D.2.10.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.10.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.10.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.11. Package ",
    FontSize->10],
  StyleBox["Weyl.m  ",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t\t\t143\n            ",
  StyleBox["D.2.11.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.11.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.11.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"]
}], "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "         ",
  StyleBox["D.2.12. Package ",
    FontSize->10],
  StyleBox["ErdelyiKober.m",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t\t144\n            ",
  StyleBox["D.2.12.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.12.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.12.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n        ",
  StyleBox["D.2.13. Package ",
    FontSize->10],
  StyleBox["Riesz.m",
    FontSize->11,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t\t\t145\n            ",
  StyleBox["D.2.13.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.13.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.13.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.14. Package ",
    FontSize->10],
  StyleBox["IntegralTrafosExtensions.m    ",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t145\n            ",
  StyleBox["D.2.14.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.14.2. New Symbols (Help Text for $Version 3.0)",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.14.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.15. Package ",
    FontSize->10],
  StyleBox["MellinBarnesSeries.m  ",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t149\n            ",
  StyleBox["D.2.15.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.15.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.15.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.16. Package ",
    FontSize->10],
  StyleBox["Integral.m",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t\t\t150\n            ",
  StyleBox["D.2.16.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.16.2. New Symbols",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.16.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n         ",
  StyleBox["D.2.17. Package ",
    FontSize->10],
  StyleBox["FractalDSolve.m",
    FontSize->10,
    FontSlant->"Italic"],
  "\t\t\t\t\t\t\t\t151\n            ",
  StyleBox["D.2.17.1. Task",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.17.2. New Symbol",
    FontSize->10,
    FontSlant->"Italic"],
  "\n            ",
  StyleBox["D.2.17.3. Further Properties",
    FontSize->10,
    FontSlant->"Italic"],
  "\n      D.3. Protocol\t\t\t\t\t\t\t\t\t\t\t152\n      D.4. Remarks\t\t\t\t\
\t\t\t\t\t\t\t152"
}], "Text"],

Cell["\<\
   E. Abbreviations\t\t\t\t\t\t\t\t\t\t\t153
      E.1. Motivation\t\t\t\t\t\t\t\t\t\t\t153
      E.2. Symbols of Physical Quantity and Units\t\t\t\t\t\t\t153
      E.3. Further Abbreviations\t\t\t\t\t\t\t\t\t154\
\>", "Text"],

Cell["\<\
   F. Measured Data\t\t\t\t\t\t\t\t\t\t\t155
      F.1. Motivation\t\t\t\t\t\t\t\t\t\t\t155
      F.2. Measured Data by T. Zavada  \t\t\t\t\t\t\t\t155
      F.3. Measured Data by Wei Q.-H.  \t\t\t\t\t\t\t\t156\
\>", "Text"],

Cell[TextData[{
  StyleBox["References",
    FontWeight->"Bold"],
  "\t\t\t\t\t\t\t\t\t\t\t\t",
  StyleBox["159",
    FontWeight->"Bold"]
}], "Text"],

Cell["\<\
   Thanks\t\t\t\t\t\t\t\t\t\t\t\t165
   Declaration\t\t\t\t\t\t\t\t\t\t\t\t167
   Curriculum Vitae\t\t\t\t\t\t\t\t\t\t\t169\
\>", "Text"],

Cell[TextData[{
  StyleBox["Zusammenfassung (German Summary)",
    FontWeight->"Bold"],
  "\t\t\t\t\t\t\t\t",
  StyleBox["171",
    FontWeight->"Bold"]
}], "Text",
  PageBreakAbove->True],

Cell[TextData[StyleBox[
"   1. Varianztheorem\t\t\t\t\t\t\t\t\t\t\t171\n   2. Delta-Funktion\t\t\t\t\t\
\t\t\t\t\t\t172\n   3. Anomale Diffusion\t\t\t\t\t\t\t\t\t\t172\n   4. \
Kernmagnetische Relaxation\t\t\t\t\t\t\t\t\t173\n   5. Diffusionsmessung\t\t\t\
\t\t\t\t\t\t\t174\n   6. Computeralgebra\t\t\t\t\t\t\t\t\t\t\t174\n   7. \
Ausblick\t\t\t\t\t\t\t\t\t\t\t\t175",
  FontWeight->"Plain"]], "Text"],

Cell[TextData[{
  StyleBox["Errata (State: 2015)",
    FontWeight->"Bold"],
  "\t\t\t\t\t\t\t\t\t\t\t",
  StyleBox["177",
    FontWeight->"Bold"]
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 742}},
ScreenStyleEnvironment->"Printout",
PrintingStyleEnvironment->"Printout",
ShowPageBreaks->True,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1248, 719},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->5,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Table of Contents"}], "Header"]}, {Cell[ 
        TextData[ {"Table of Contents"}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
PrivateFontOptions->{"FontType"->"Outline"},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> "TeX-German.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 72, 1, 109, "Title",
  CounterAssignments->{{"Title", 3}}],
Cell[1806, 54, 152, 6, 33, "Text"],
Cell[1961, 62, 163, 6, 33, "Text"],
Cell[2127, 70, 1310, 35, 332, "Text"],
Cell[3440, 107, 1054, 29, 252, "Text"],
Cell[4497, 138, 369, 6, 112, "Text"],
Cell[4869, 146, 81, 1, 32, "Text",
  PageBreakBelow->True],
Cell[4953, 149, 159, 6, 33, "Text"],
Cell[5115, 157, 60, 0, 32, "Text"],
Cell[5178, 159, 1460, 40, 332, "Text"],
Cell[6641, 201, 1034, 29, 252, "Text"],
Cell[7678, 232, 875, 25, 232, "Text"],
Cell[8556, 259, 81, 1, 32, "Text",
  PageBreakBelow->True],
Cell[8640, 262, 175, 6, 33, "Text"],
Cell[8818, 270, 1162, 31, 272, "Text"],
Cell[9983, 303, 544, 15, 152, "Text"],
Cell[10530, 320, 854, 24, 212, "Text"],
Cell[11387, 346, 81, 1, 32, "Text",
  PageBreakBelow->True],
Cell[11471, 349, 173, 6, 33, "Text"],
Cell[11647, 357, 67, 0, 32, "Text"],
Cell[11717, 359, 507, 10, 132, "Text"],
Cell[12227, 371, 406, 10, 92, "Text"],
Cell[12636, 383, 66, 3, 52, "Text"],
Cell[12705, 388, 188, 6, 33, "Text"],
Cell[12896, 396, 879, 24, 212, "Text"],
Cell[13778, 422, 1013, 31, 272, "Text"],
Cell[14794, 455, 80, 1, 32, "Text",
  PageBreakBelow->True],
Cell[14877, 458, 146, 6, 33, "Text"],
Cell[15026, 466, 355, 8, 152, "Text"],
Cell[15384, 476, 149, 6, 33, "Text"],
Cell[15536, 484, 226, 5, 92, "Text"],
Cell[15765, 491, 878, 28, 272, "Text"],
Cell[16646, 521, 893, 25, 192, "Text",
  PageBreakBelow->True],
Cell[17542, 548, 4989, 196, 872, "Text",
  PageBreakBelow->True],
Cell[22534, 746, 2916, 111, 534, "Text"],
Cell[25453, 859, 236, 5, 92, "Text"],
Cell[25692, 866, 233, 5, 92, "Text"],
Cell[25928, 873, 149, 6, 33, "Text"],
Cell[26080, 881, 147, 4, 72, "Text"],
Cell[26230, 887, 187, 7, 33, "Text",
  PageBreakAbove->True],
Cell[26420, 896, 402, 6, 152, "Text"],
Cell[26825, 904, 157, 6, 33, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

